#!/usr/bin/env python
# -*- coding: utf-8 -*-

import matplotlib as mpl
mpl.use('pdf')

import numpy as np
from matplotlib.externals import six
import matplotlib.pyplot as plt

fig_size =  [12,10]


# For available TeX fonts with math support, see 
# http://www.tug.dk/FontCatalogue/mathfonts.html
############################ Latex ##########################
#SERIF
params = {'text.usetex': True, 'font.family': 'serif', 'font.serif': 'Palatino', 'font.size': 28, 'text.latex.preamble': {r'\usepackage{newpxtext,newpxmath}', r'\usepackage[T1]{fontenc}', r'\usepackage[utf8]{inputenx}', r'\usepackage{amsmath}'}, 'xtick.major.pad': 7, 'figure.figsize': fig_size}
#params = {'text.usetex': True, 'font.family': 'serif', 'font.serif': 'Fourier', 'font.size': 30, 'text.latex.preamble': {r'\usepackage{fourier}', r'\usepackage[T1]{fontenc}', r'\usepackage[utf8]{inputenx}', r'\usepackage{amsmath}'}, 'xtick.major.pad': 7, 'figure.figsize': fig_size}

#SANS SERIF
#params = {'text.usetex': True, 'font.family': 'sans-serif', 'font.sans-serif': 'kurier', 'font.size': 28, 'text.latex.preamble': {r'\usepackage[math]{kurier}', r'\usepackage[T1]{fontenc}', r'\usepackage[utf8]{inputenx}', r'\usepackage{amsmath}'}, 'xtick.major.pad': 7, 'figure.figsize': fig_size}
#params = {'text.usetex': True, 'font.family': 'sans-serif', 'font.sans-serif': 'cm', 'font.size': 28, 'text.latex.preamble': {r'\usepackage{cmbright}', r'\usepackage[T1]{fontenc}', r'\usepackage[utf8]{inputenx}', r'\usepackage{amsmath}'}, 'xtick.major.pad': 7, 'figure.figsize': fig_size}
#############################################################

mpl.rcParams.update(params)

fig11x, fig11y = np.loadtxt('fig11.dat', unpack='true')
fig12x, fig12y = np.loadtxt('fig12.dat', unpack='true')
fig13x, fig13y = np.loadtxt('fig13.dat', unpack='true')
fig14x, fig14y = np.loadtxt('fig14.dat', unpack='true')
fig15x, fig15y = np.loadtxt('fig15.dat', unpack='true')

#for special linestyle, see
#http://philbull.wordpress.com/2012/03/14/custom-dashdot-line-styles-in-matplotlib/
#https://stackoverflow.com/questions/14710221/python-matplotlib-dash-dot-dot-how-to

fig = plt.figure()

ax1=plt.subplot(111)
plt.loglog(fig13x,fig13y, color='blue', ls='-', linewidth=4, label=r'MC (Sec. 4.1)')
spplot2=plt.loglog(fig15x,fig15y, color='green', linewidth=4, label=r'Eqs. (20)--(22)') 
spplot2[0].set_dashes([16, 4])
spplot1=plt.loglog(fig14x,fig14y, color='red', linewidth=4, label=r'Eq. (25)')
spplot1[0].set_dashes([16, 8, 4, 8, 4, 8])
plt.loglog(fig11x,1.5*fig11y, 'k-', linewidth=2)
plt.loglog(fig12x,fig12y, 'k--', linewidth=2)
plt.axis([1,1e12,1e-17,1e-5])
plt.gca().xaxis.set_ticks_position('bottom')
plt.gca().yaxis.set_ticks_position('left')
plt.tick_params(which = 'both', length = 8,width = 1)
plt.xlabel('Time (ns)')
plt.ylabel('Photon flux (nm$^{-2}$ ns$^{-1})$')
ax1.set_xticks((1,1e2,1e4,1e6,1e8,1e10,1e12))
ax1.set_yticks((1e-16,1e-14,1e-12,1e-10,1e-8,1e-6))
plt.text(0.47, 0.26, r'$\tau^{-1}\log(\tau)^{-3}$', transform = ax1.transAxes, color = 'k')
plt.text(0.77, 0.35, r'$\tau^{-1}\log(\tau)^{-2}$', transform = ax1.transAxes, color = 'k')
plt.legend(loc='lower left', prop={'size':28}, frameon=False, shadow=False, fancybox=False, markerscale=1, handlelength=3)

plt.text(0.1, 0.55, r'oha, \LaTeX!', transform = ax1.transAxes, color = 'k')
plt.text(0.55, 0.62, r'\LaTeX\ math: $\lambda=\sum_i^\infty \mu_i^2$', transform = ax1.transAxes, color = 'k')

plt.subplots_adjust(left = 0.14, right = 0.96, top = 0.99, bottom = 0.1, hspace = 0.01, wspace = 0.01)

fig.savefig('fig1_tex.pdf')
#fig.show()
